"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ComponentMethods = void 0;
class ComponentMethods {
    constructor(testRendererState) {
        this.addWrapper = (component, props) => {
            this.trs.wrappers.push({ component, props: props !== null && props !== void 0 ? props : {}, type: 'component' });
            return this.trs.wrappers.length - 1;
        };
        this.addContextProvider = (context, value) => {
            this.trs.wrappers.push({ component: context.Provider, props: { value }, type: 'context' });
            return this.trs.wrappers.length - 1;
        };
        this.addTemporaryWrapper = (component, props) => {
            this.createTemporaryWrappers();
            this.trs.temporaryWrappers.push({ component, props, type: 'component' });
            this.enableTemporaryWrappers();
        };
        this.useWrapperProps = (id, props) => {
            this.createTemporaryWrappers();
            if (!this.isValidIndex(id)) {
                throw Error(`useWrapperProps 'id' is not valid, id is: ${id} ` +
                    `the wrapper array has a length of ${this.trs.temporaryWrappers.length}`);
            }
            const wrapperArray = this.trs.temporaryWrappers;
            if (wrapperArray[id].type !== 'component') {
                throw Error(`useWrapperprops 'id' refers to a a type of '${wrapperArray[id].type}' not of type 'component'`);
            }
            wrapperArray[id] = Object.assign(Object.assign({}, wrapperArray[id]), { props });
            this.enableTemporaryWrappers();
        };
        this.useContextValue = (id, value) => {
            this.createTemporaryWrappers();
            if (!this.isValidIndex(id)) {
                throw Error(`useContextValue 'id' is not valid, id is: ${id} ` +
                    `the wrapper array has a length of ${this.trs.temporaryWrappers.length}`);
            }
            const wrapperArray = this.trs.temporaryWrappers;
            if (wrapperArray[id].type !== 'context') {
                throw Error(`useContextValue 'id' refers to a a type of '${wrapperArray[id].type}' not of type 'context'`);
            }
            wrapperArray[id] = Object.assign(Object.assign({}, wrapperArray[id]), { props: { value } });
            this.enableTemporaryWrappers();
        };
        this.enableTemporaryWrappers = () => {
            this.trs.useTemporaryWrappers = true;
        };
        this.createTemporaryWrappers = () => {
            if (!this.trs.useTemporaryWrappers) {
                this.trs.temporaryWrappers = [...this.trs.wrappers];
            }
        };
        this.isValidIndex = (id) => id >= 0 && id < this.trs.temporaryWrappers.length;
        this.trs = testRendererState;
    }
}
exports.ComponentMethods = ComponentMethods;
