"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RenderMethods = void 0;
const react_1 = require("react");
const react_2 = require("@testing-library/react");
const react_redux_1 = require("react-redux");
class RenderMethods {
    constructor(testRendererState) {
        this.render = (props, children) => {
            const usingTemporaryWrappers = this.trs.useTemporaryWrappers;
            const renderResult = react_2.render(this.buildComponent(props, children));
            return Object.assign(Object.assign({}, renderResult), { rerender: (newProps) => {
                    this.trs.useTemporaryWrappers = usingTemporaryWrappers;
                    renderResult.rerender(this.buildComponent(newProps, children));
                } });
        };
        this.renderWithStore = (props, state, children) => {
            this.trs.setState(state);
            const store = this.trs.setStore();
            const usingTemporaryWrappers = this.trs.useTemporaryWrappers;
            const wrappedComponent = this.wrapWithProvider(store, this.buildComponent(props, children));
            const renderResult = react_2.render(wrappedComponent);
            return Object.assign(Object.assign({}, renderResult), { store, rerender: (newProps) => {
                    this.trs.useTemporaryWrappers = usingTemporaryWrappers;
                    return renderResult.rerender(this.wrapWithProvider(store, this.buildComponent(newProps, children)));
                } });
        };
        this.buildComponent = (props, children) => {
            const component = this.createBaseComponent(props, children);
            if (this.trs.useTemporaryWrappers) {
                this.trs.useTemporaryWrappers = false;
                return this.wrapWithWrapperArray(this.trs.temporaryWrappers, component);
            }
            return this.wrapWithWrapperArray(this.trs.wrappers, component);
        };
        this.wrapWithWrapperArray = (array, component) => {
            let wrappedElement = component;
            array.forEach((wrapper) => {
                wrappedElement = this.wrapWithWrapper(wrappedElement, wrapper);
            });
            return wrappedElement;
        };
        this.wrapWithWrapper = (component, wrapper) => react_1.createElement(wrapper.component, Object.assign({}, wrapper.props), component);
        this.wrapWithProvider = (store, childComponent) => this.wrapWithWrapper(childComponent, { component: react_redux_1.Provider, props: { store }, type: 'provider' });
        this.createBaseComponent = (props, children = []) => react_1.createElement(this.trs.component, props || this.trs.defaultProps, ...children);
        this.trs = testRendererState;
    }
}
exports.RenderMethods = RenderMethods;
